@@ -203,10 +203,6 @@ class Department(flow.Object):
         )
     )
     auto_current = flow.BoolParam(True).ui(hidden=True)
-
-    create_defaults = flow.Child(CreateDefaultFileSystemItemsAction).ui(
-        label="Create default files"
-    )
     show_environment = flow.Child(GotoContextualEnv)
     path = flow.Computed(cached=True).ui(hidden=True)
 
