@@ -5,37 +5,156 @@ import re
 from collections import defaultdict
 
 from kabaret import flow
+from kabaret.flow_entities.entities import Entity, EntityCollection, Property
+from kabaret.flow_contextual_dict import get_contextual_dict
 
 from .maputils import SimpleCreateAction
 
 
-class DependencyTemplate(flow.Object):
+# class DependencyTemplate(flow.Object):
 
-    dependencies = flow.Param('').ui(editor='textarea')
-    defaults = flow.OrderedStringSetParam()
+#     dependencies = flow.Param('').ui(editor='textarea')
+#     defaults = flow.OrderedStringSetParam()
 
-    def get_dependencies(self):
-        return json.loads(self.dependencies.get())
+#     def get_dependencies(self):
+#         return json.loads(self.dependencies.get())
 
-    def get_default_dependency_names(self):
-        return self.defaults.get()
+#     def get_default_dependency_names(self):
+#         return self.defaults.get()
 
-    def get_dependency_files(self, name):
-        deps = self.get_dependencies()[name]
+#     def get_dependency_files(self, name):
+#         deps = self.get_dependencies()[name]
         
-        if 'files' in deps:
-            return deps['files']
+#         if 'files' in deps:
+#             return deps['files']
         
-        return deps
+#         return deps
 
-    def get_asset_files(self, asset_name):
-        kitsu_bindings = self.root().project().kitsu_bindings()
-        asset = kitsu_bindings.get_asset_data(asset_name)
+#     def get_asset_files(self, asset_name):
+#         kitsu_bindings = self.root().project().kitsu_bindings()
+#         asset = kitsu_bindings.get_asset_data(asset_name)
 
-        return self.get_dependency_files('kitsu.'+asset['type'])
+#         return self.get_dependency_files('kitsu.'+asset['type'])
 
 
-class DependencyTemplates(flow.Map):
+class EntityMap(EntityCollection):
+    '''
+    Provides a method to add a single entity,
+    required by existing creation actions.
+    '''
+
+    def add(self, name):
+        self.ensure_exist([name])
+
+
+class _SafeDict(dict):
+    '''
+    From https://stackoverflow.com/a/17215533
+    '''
+    def __init__(self, mapping, **kwargs):
+        super(_SafeDict, self).__init__(mapping, **kwargs)
+        self.missing_keys = []
+    
+    def __missing__(self, key):
+        self.missing_keys.append(key)
+        return '{' + key + '}'
+
+
+class DependencyPreset(Entity):
+
+    file_oid_pattern = Property().watched()
+    relative_oid     = Property().ui(editor='bool')
+    revision_name    = Property().ui(
+        placeholder='Leave blank to get head revision'
+    )
+
+    _template = flow.Parent(2)
+
+    def evaluate(self, start_oid=None, file_oid_keywords=None):
+        '''
+        Returns the file revision targeted by this preset.
+        '''
+        # Evaluate oid with provided keywords
+        keywords = _SafeDict(file_oid_keywords if file_oid_keywords else {})
+        oid = self.file_oid_pattern.get().format_map(keywords)
+        
+        if keywords.missing_keys:
+            self.root().session().log_warning((
+                f'Dependency template :: {self._template.name()}.{self.name()}: '
+                 'The following keywords could not be evaluated: '
+                 + str(keywords.missing_keys)
+            ))
+            return None
+        
+        # Resolve oid
+        if self.relative_oid.get():
+            if start_oid is not None:
+                oid = start_oid + '/' + oid
+            else:
+                self.root().session().log_warning((
+                    f'Dependency template :: {self._template.name()}.{self.name()}: '
+                     'Expected relative oid but no starting oid provided'
+                ))
+                return None
+        
+        try:
+            resolved_oid = self.root().session().cmds.Flow.resolve_path(oid)
+        except flow.exceptions.MissingRelationError:
+            resolved_oid = None
+        
+        revision = None
+
+        # Get target revision
+        if resolved_oid is not None:
+            file = self.root().get_object(resolved_oid)
+            revision_name = self.revision_name.get()
+
+            if not revision_name:
+                revision = file.get_head_revision()
+            else:
+                revision = file.get_revision(revision_name)
+            
+            if revision is None:
+                self.root().session().log_warning((
+                    f'Dependency template :: {self._template.name()}.{self.name()}: '
+                    f'File {resolved_oid} has no revision {revision_name}'
+                ))
+        else:
+            self.root().session().log_warning((
+                f'Dependency template :: {self._template.name()}.{self.name()}: '
+                f'No existing file with oid {oid}'
+            ))
+        
+        return revision
+    
+    def child_value_changed(self, child_value):
+        if child_value is self.file_oid_pattern:
+            pattern = self.file_oid_pattern.get()
+            project_name = self.root().project().name()
+            if (
+                not self.relative_oid.get()
+                and not pattern.startswith('/'+project_name)
+            ):
+                self.file_oid_pattern.set_watched(False)
+                self.file_oid_pattern.set('/'+project_name+'/'+pattern)
+                self.file_oid_pattern.set_watched(True)
+
+
+class DependencyPresets(EntityMap):
+
+    add_template = flow.Child(SimpleCreateAction)
+
+    @classmethod
+    def mapped_type(cls):
+        return DependencyPreset
+
+
+class DependencyTemplate(Entity):
+    
+    presets = flow.Child(DependencyPresets)
+
+
+class DependencyTemplates(EntityMap):
 
     add_template = flow.Child(SimpleCreateAction)
 
@@ -44,6 +163,25 @@ class DependencyTemplates(flow.Map):
         return DependencyTemplate
 
 
+class DependencyManager(flow.Object):
+    
+    templates = flow.Child(DependencyTemplates)
+
+    def get_revision_dependencies(self, template_name, start_oid=None, file_oid_keywords=None):
+        if not self.templates.has_mapped_name(template_name):
+            return []
+        
+        template = self.templates[template_name]
+        revisions = []
+
+        for p in template.presets.mapped_items():
+            r = p.evaluate(start_oid, file_oid_keywords)
+            if r is not None:
+                revisions.append(r)
+        
+        return revisions
+
+
 class FileSystemItem:
 
     def __init__(self, entity_name, entity_oid, department, name, revision, project):
