@@ -26,29 +26,29 @@ class OpenFileAction(RunAction):
 
     def allow_context(self, context):
         ext = os.path.splitext(self._file.path.get())[1]
-        valid_ext = self.supported_extensions() is None or ext in self.supported_extensions()
+        valid_ext = (
+            self.supported_extensions() is None or ext in self.supported_extensions()
+        )
 
-        return context and context.endswith('.map') and valid_ext
+        return context and context.endswith(".map") and valid_ext
 
     def extra_argv(self):
         return [self._file.path.get()]
 
 
 class OpenWithBlenderAction(OpenFileAction):
-
     @classmethod
     def supported_extensions(cls):
-        return ['.blend']
+        return [".blend"]
 
     def runner_name_and_tags(self):
-        return 'Blender', []
+        return "Blender", []
 
 
 class OpenWithKritaAction(OpenFileAction):
-
     @classmethod
     def supported_extensions(cls):
-        return ['.kra', '.png', '.jpg']
+        return [".kra", ".png", ".jpg"]
 
     def runner_name_and_tags(self):
-        return 'Krita', []
+        return "Krita", []
