@@ -27,6 +27,14 @@ class Shot(Entity):
     def get_default_contextual_edits(self, context_name):
         if context_name == 'settings':
             return dict(shot=self.name())
+    
+    def get_default_tasks(self, force_update=False):
+        mgr = self.root().project().get_task_manager()
+        default_tasks = mgr.default_tasks.mapped_names()
+        return default_tasks
+    
+    def _fill_ui(self, ui):
+        ui['custom_page'] = 'libreflow.baseflow.ui.task.TasksCustomWidget'
 
 
 class ShotCollection(EntityView):
