@@ -185,10 +185,10 @@ class CreateTaskDefaultFiles(flow.Action):
 
 class FileTypeValue(flow.values.SessionValue):
 
-    DEFAULT_PATH_FORMAT = 'choice'
+    DEFAULT_EDITOR = 'choice'
 
     def choices(self):
-        return ['INPUT', 'OUTPUT', 'WORK']
+        return ['Inputs', 'Outputs', 'Works']
 
 
 class PathFormatValue(flow.values.SessionValue):
@@ -212,7 +212,7 @@ class CreateDefaultFileAction(flow.Action):
     file_name   = flow.SessionParam('').ui(
         placeholder='layout.blend'
     )
-    file_type   = flow.SessionParam('WORK', FileTypeValue)
+    file_type   = flow.SessionParam(None, FileTypeValue)
     path_format = flow.SessionParam(DEFAULT_PATH_FORMAT, PathFormatValue).ui(
         placeholder='{film}/{shot}/{file}/{revision}'
     )
@@ -237,6 +237,7 @@ class CreateDefaultFileAction(flow.Action):
 
         df = self._map.add(mapped_name)
         df.file_name.set(self.file_name.get())
+        df.file_type.set(self.file_type.get())
         df.enabled.set(self.enabled.get())
         df.optional.set(self.optional.get())
         df.path_format.set(path_format)
@@ -360,6 +361,7 @@ class EditDefaultTaskFile(flow.Action):
     path_format = flow.SessionParam(DEFAULT_PATH_FORMAT, PathFormatValue).ui(
         placeholder='{film}/{shot}/{file}/{revision}'
     )
+    file_type   = flow.SessionParam(None, FileTypeValue)
     enabled     = flow.SessionParam().ui(editor='bool')
     optional    = flow.SessionParam().ui(editor='bool')
 
@@ -369,6 +371,7 @@ class EditDefaultTaskFile(flow.Action):
 
     def get_buttons(self):
         self.message.set(f'<h2>Edit default file {self._dft_file.file_name.get()}</h2>')
+        self.file_type.set(self._dft_file.file_type.get())
         self.path_format.set(self._dft_file.path_format.get())
         self.enabled.set(self._dft_file.enabled.get())
         self.optional.set(self._dft_file.optional.get())
@@ -398,6 +401,7 @@ class EditDefaultTaskFile(flow.Action):
                 dft_file = self._map.edits.add(self._dft_file.name())
                 dft_file.file_name.set(file_name)
             
+            dft_file.file_type.set(self.file_type.get())
             dft_file.path_format.set(self.path_format.get())
             dft_file.enabled.set(self.enabled.get())
             dft_file.optional.set(self.optional.get())
@@ -412,6 +416,7 @@ class AddDefaultTaskFileEdit(flow.Action):
     """
 
     file_name   = flow.SessionParam('').ui(label='Name')
+    file_type   = flow.SessionParam(None, FileTypeValue)
     path_format = flow.SessionParam(DEFAULT_PATH_FORMAT, PathFormatValue)
     enabled     = flow.SessionParam(True).ui(editor='bool')
     optional    = flow.SessionParam(False).ui(editor='bool')
@@ -437,6 +442,7 @@ class AddDefaultTaskFileEdit(flow.Action):
         file_name = self.file_name.get()
         df = self._map.edits.add(file_name.replace('.', '_'))
         df.file_name.set(self.file_name.get())
+        df.file_type.set(self.file_type.get())
         df.path_format.set(self.path_format.get())
         df.enabled.set(self.enabled.get())
         df.optional.set(self.optional.get())
@@ -469,6 +475,7 @@ class DefaultTaskFile(flow.SessionObject):
 
     file_name   = flow.Param().ui(editable=False)
     path_format = flow.Param().ui(editable=False)
+    file_type   = flow.Param().ui(editable=False)
     enabled     = flow.BoolParam().ui(editable=False)
     optional    = flow.BoolParam().ui(editable=False)
     is_edit     = flow.BoolParam().ui(editable=False)
@@ -506,6 +513,7 @@ class DefaultTaskFiles(flow.DynamicMap):
                 data['is_edit'] = False
             data.update(dict(
                 file_name=default_file.file_name.get(),
+                file_type=default_file.file_type.get(),
                 path_format=default_file.path_format.get(),
                 enabled=default_file.enabled.get(),
                 optional=default_file.optional.get()
@@ -517,6 +525,7 @@ class DefaultTaskFiles(flow.DynamicMap):
             default_file = self.edits[name]
             data = dict(
                 file_name=default_file.file_name.get(),
+                file_type=default_file.file_type.get(),
                 path_format=default_file.path_format.get(),
                 enabled=default_file.enabled.get(),
                 optional=default_file.optional.get(),
@@ -532,6 +541,7 @@ class DefaultTaskFiles(flow.DynamicMap):
     
     def _configure_child(self, child):
         child.file_name.set(self._cache[child.name()]['file_name'])
+        child.file_type.set(self._cache[child.name()]['file_type'])
         child.path_format.set(self._cache[child.name()]['path_format'])
         child.enabled.set(self._cache[child.name()]['enabled'])
         child.optional.set(self._cache[child.name()]['optional'])
