@@ -1,7 +1,6 @@
 import os
 import re
 import timeago
-from tkinter import Tk
 from datetime import datetime
 from kabaret.app import resources
 from kabaret.app.ui.gui.widgets.widget_view import DockedView, QtWidgets, QtGui, QtCore
@@ -148,16 +147,10 @@ class OutputHeader(QtWidgets.QWidget):
             self._textedit_cmd.setPlainText(current_item.command())
 
     def copy_cmd_to_clipboard(self):
-        '''
-        Copies the given string content to the system clipboard.
-        From https://stackoverflow.com/questions/579687/how-do-i-copy-a-string-to-the-clipboard
-        '''
-        r = Tk()
-        r.withdraw()
-        r.clipboard_clear()
-        r.clipboard_append(self._textedit_cmd.toPlainText())
-        r.update()
-        r.destroy()
+        cmd = self._textedit_cmd.toPlainText()
+        app = QtWidgets.QApplication.instance()
+        clip = app.clipboard()
+        clip.setText(cmd)
 
 
 class OutputTextEdit(QtWidgets.QPlainTextEdit):
